Description

A convenient way to use Qlik Sense Engine API from Python
View and edit master measures, master dimensions, variables and sheet objects in pythonic way


```python
Installation

pip install qsea
```
